<?php

/**
 * JUrlManager class file.
 *
 * @author jerry2801 <jerry2801@gmail.com>
 * @version 1.0
 *
 */

class JUrlManager extends CUrlManager
{
    public $langUrlParamName = 'lang';
    public $langCookieParamName = 'lang';

    /**
     * Get All Languages
     *
     * 'en_us' => array(
     *     'label'=>'English',
     *     'dateFormat'=>'d-M-Y',
     * ),
     * 'zh_cn' => array(
     *     'label'=>'中文',
     *     'dateFormat'=>'Y-m-d',
     * ),
     *
     */
    public function getLanguages()
    {
        return include Yii::app()->basePath.DIRECTORY_SEPARATOR.'config'.DIRECTORY_SEPARATOR.'languages.php';
    }

    public function parseUrl($request)
    {
        $languages=$this->languages;
        $ret = parent::parseUrl($request);
        $langCookie = Yii::app()->request->cookies[$this->langCookieParamName];
        $cookieLanguage = $langCookie ? $langCookie->value : null;
        if(isset($_GET[$this->langUrlParamName]) && isset($languages[ $_GET[$this->langUrlParamName] ]))
        {
            Yii::app()->language = $_GET[$this->langUrlParamName];
            Yii::app()->request->cookies[$this->langCookieParamName] = new CHttpCookie($this->langCookieParamName, Yii::app()->language);
        }
        elseif($cookieLanguage && isset($languages[ $cookieLanguage ]))
        {
            Yii::app()->language = $cookieLanguage;
        }
        else
        {
            $preferredLanguage = Yii::app()->getRequest()->getPreferredLanguage();

            if(isset($languages[ $preferredLanguage ]))
                Yii::app()->language = $preferredLanguage;
            else
            {
                $languageKeys=array_keys($languages);
                Yii::app()->language = reset($languageKeys);
            }

            Yii::app()->request->cookies[$this->langCookieParamName] = new CHttpCookie($this->langCookieParamName, Yii::app()->language);
        }
        
        return $ret;
    }

}